@@ -3,14 +3,15 @@ import unittest
 import tempfile
 import time
 from sqlitedict import SqliteDict
+import pathlib
 
-from artap.problem import Problem, ProblemViewDataStore
-from artap.datastore import FileDataStore
-from artap.algorithm_scipy import ScipyOpt
-from artap.algorithm_sweep import SweepAlgorithm
+from ..problem import Problem, ProblemViewDataStore
+from ..datastore import FileDataStore
+from ..algorithm_scipy import ScipyOpt
+from ..algorithm_sweep import SweepAlgorithm
 
-from artap.results import Results
-from artap.operators import RandomGenerator, CustomGenerator
+from ..results import Results
+from ..operators import RandomGenerator, CustomGenerator
 
 from sys import platform
 if platform == "win32":
@@ -40,9 +41,9 @@ class MyProblem(Problem):
 class TestDataStoreFile(unittest.TestCase):
     def test_read_write_database(self):
         problem = MyProblem()
-
         # set data store
-        database_name = tempfile.NamedTemporaryFile(mode="w", delete=False, dir=None, suffix=".sqlite").name
+        # database_name = tempfile.NamedTemporaryFile(mode="w", delete=False, dir=None, suffix=".sqlite").name
+        database_name = 'data.sqlite'
         problem.data_store = FileDataStore(problem, database_name=database_name)
 
         algorithm = ScipyOpt(problem)
@@ -51,52 +52,35 @@ class TestDataStoreFile(unittest.TestCase):
         algorithm.options['verbose_level'] = 0
         algorithm.run()
 
-        results = Results(problem)
-        optimum = results.find_optimum('F')
-        self.assertAlmostEqual(optimum.costs[0], 0, 3)
-
         # remove datastore
         problem.data_store.destroy()
 
         # check db
-        db = SqliteDict(database_name, autocommit=True)
-
+        db = SqliteDict(database_name, flag='r')
         populations = db["populations"]
-
-        individual = populations[-1].individuals[9]
-        self.assertAlmostEqual(individual.costs[0], 0, 3) # result
-        self.assertAlmostEqual(individual.custom["functions"][0], individual.vector[0]**2)
+        individual = populations[-1].individuals[-1]
+        print(individual)
         db.close()
 
+        self.assertAlmostEqual(individual.costs[0], 0, 3) # result
+        self.assertAlmostEqual(individual.custom["functions"][0], individual.vector[0]**2)
+
         # remove file
-        # print(database_name)
         os.remove(database_name)
 
-    def xtest_read_datastore(self):
-        problem = MyProblem()
-
-        database_name = tempfile.NamedTemporaryFile(mode="w", delete=False, dir=None, suffix=".sqlite").name
-        problem.data_store = FileDataStore(problem, database_name=database_name, mode="REWRITE")
-
-        gen = CustomGenerator(problem.parameters)
-        gen.init([[1, 2], [3, 3]])
-
-        algorithm = SweepAlgorithm(problem, generator=gen)
-        algorithm.run()
-
-        problem.data_store.destroy()
-
     def test_read_datastore(self):
-        database_name = "data" + os.sep + "data.sqlite"
+        # Path to this script file location
+        file_path =str(pathlib.Path(__file__).parent.absolute())
+        database_name = os.path.join(file_path, "data/data.sqlite")
         problem = ProblemViewDataStore(database_name=database_name)
 
         self.assertEqual(problem.name, 'NLopt_BOBYQA')
 
         individuals = problem.populations[-1].individuals
-        self.assertEqual(individuals[0].vector[0], 1)
-        self.assertEqual(individuals[1].vector[1], 3)
-        self.assertEqual(individuals[0].costs, [5])
-        self.assertEqual(individuals[1].costs, [18])
+        self.assertAlmostEqual(individuals[0].vector[1], 2, 4)
+        self.assertAlmostEqual(individuals[1].vector[0], 3, 4)
+        self.assertAlmostEqual(individuals[0].costs[0], 5, 4)
+        self.assertAlmostEqual(individuals[1].costs[0], 18, 4)
 
 
 class TestDataStoreFileBenchmark(unittest.TestCase):
